Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DeleteTrades ¶
DeleteTrades will remove trades from the database using trade.Data
func VerifyTradeInIntervals ¶
func VerifyTradeInIntervals(exchangeName, assetType, base, quote string, irh *kline.IntervalRangeHolder) error
VerifyTradeInIntervals will query for ONE trade within each kline interval and verify if data exists if it does, it will set the range holder property "HasData" to true
Types ¶
type Data ¶
type Data struct {
ID string
TID string
Exchange string
ExchangeNameID string
Base string
Quote string
AssetType string
Price float64
Amount float64
Side string
Timestamp time.Time
}
Data defines trade data in its simplest db friendly form
Click to show internal directories.
Click to hide internal directories.